Module codegen

Module codegen 

Re-exports

pub use crate::config::Config;

Structs

SpecInfo
Metadata about the OpenAPI spec being generated from.

Constants

PARAM_LOCATIONS
The canonical ordering for parameter locations in generated signatures.
RUST_KEYWORDS

Functions

generate_doc_comment
generate_operations
Generate Rust source code for a list of operations.
generate_operations_tokens
Generate token streams for a list of operations.
generate_types
Generate Rust source code for a list of type definitions.
generate_types_tokens
Generate token streams for a list of type definitions.
generated_file_banner
Generate the banner comment prepended to every generated file.
generated_file_preamble
Emit file-level #![allow(...)] attributes to suppress expected lints in generated code.
group_by_tag
location_arg_name
location_suffix
multipart_body_struct_name
Return the body struct name for a multipart operation, if it has fields.
primitive_to_tokens
status_code_variant_name
to_pascal_ident
to_snake_ident
type_ref_to_tokens